==> haskell-keys-3.12.3-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-keys.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 keys
version:              3.12.3
visibility:           public
id:                   keys-3.12.3-88yDI6snSOKGHxgWKZnNbo
key:                  keys-3.12.3-88yDI6snSOKGHxgWKZnNbo
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/keys/
synopsis:             Keyed functors and containers
description:
    This package provides a bunch of ad hoc classes for accessing parts of a container.

    In practice this package is largely subsumed by the
    <https://hackage.haskell.org/package/lens lens package>,
    but it is maintained for now as it has much
    simpler dependencies.

category:             Data Structures, Containers
abi:                  108095781ec4c30eb8c145a5a6ae3796
exposed:              True
exposed-modules:      Data.Key
import-dirs:          /usr/lib/ghc-8.8.2/site-local/keys-3.12.3
library-dirs:         /usr/lib/ghc-8.8.2/site-local/keys-3.12.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/keys-3.12.3
hs-libraries:         HSkeys-3.12.3-88yDI6snSOKGHxgWKZnNbo
depends:
    array-0.5.4.0 base-4.13.0.0 comonad-5.0.6-J1GYwepYiMm1OqJKe3R0Ba
    containers-0.6.2.1 free-5.1.3-Jr1dWvVHEwCLukWPyAwQCl
    hashable-1.2.7.0-BxGxAJSPpuh3YKsULesjmE
    semigroupoids-5.3.4-cMNkWmY5857A2aljIfeBw
    tagged-0.8.6-LfhHZ57rMjK9JkdnSRh9cF transformers-0.5.6.2
    transformers-compat-0.6.5-JSMUn8oEOEx4KSfZBSghWS
    unordered-containers-0.2.10.0-7SjMUGSLAdi81baGHdq4uZ

haddock-interfaces:   /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html:         /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-keys-3.12.3-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-keys.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 keys
version:              3.12.3
visibility:           public
id:                   keys-3.12.3-FkDRA9AUeJI5Jb9RrgHJw
key:                  keys-3.12.3-FkDRA9AUeJI5Jb9RrgHJw
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/keys/
synopsis:             Keyed functors and containers
description:
    This package provides a bunch of ad hoc classes for accessing parts of a container.

    In practice this package is largely subsumed by the
    <https://hackage.haskell.org/package/lens lens package>,
    but it is maintained for now as it has much
    simpler dependencies.

category:             Data Structures, Containers
abi:                  350b6109a1a40cf6940e09b8154a1569
exposed:              True
exposed-modules:      Data.Key
import-dirs:          /usr/lib/ghc-8.8.3/site-local/keys-3.12.3
library-dirs:         /usr/lib/ghc-8.8.3/site-local/keys-3.12.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/keys-3.12.3
hs-libraries:         HSkeys-3.12.3-FkDRA9AUeJI5Jb9RrgHJw
depends:
    array-0.5.4.0 base-4.13.0.0 comonad-5.0.6-9vmfn63yZ5TCVSvE579Krk
    containers-0.6.2.1 free-5.1.3-3eyWieCaIrnv85bVDjUpu
    hashable-1.2.7.0-BxGxAJSPpuh3YKsULesjmE
    semigroupoids-5.3.4-AKGKL2lrjmi1GbOLdy8tuN
    tagged-0.8.6-LfhHZ57rMjK9JkdnSRh9cF transformers-0.5.6.2
    transformers-compat-0.6.5-JSMUn8oEOEx4KSfZBSghWS
    unordered-containers-0.2.10.0-1E0nFKYS8XWLVv5PGwMT0V

haddock-interfaces:   /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html:         /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
